@@ -25,8 +25,8 @@ from oslo_log import log as logging
 from oslo_utils import units
 
 from os_win._i18n import _LE
+from os_win import constants
 from os_win import exceptions
-from os_win.utils import constants
 from os_win.utils import win32utils
 
 LOG = logging.getLogger(__name__)
