@@ -39,8 +39,8 @@ if sys.platform == 'win32':
 from oslo_log import log as logging
 
 from os_win._i18n import _
+from os_win import constants
 from os_win import exceptions
-from os_win.utils import constants
 from os_win.utils.storage.virtdisk import (
     virtdisk_constants as vdisk_const)
 from os_win.utils import win32utils
